
# Task Types
This section examines coverage and performance across task types in SEB. The task types categories are derived from the MTEB benchmark.


## Performance across Tasks Types
The table show the performance across task types:

<iframe title="Task type SEB" aria-label="Table" id="datawrapper-chart-4jkip" src="https://datawrapper.dwcdn.net/4jkip/6/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="1160" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r=0;r<e.length;r++)if(e[r].contentWindow===a.source){var i=a.data["datawrapper-height"][t]+"px";e[r].style.height=i}}}))}();
</script>


## Coverage
The follows table give you and an overview of the coverage of the tasks: 



|                     |                          |               Across               |         ·           Danish         |          Norwegian Bokmål          |         Norwegian Nynorsk          |              Swedish               |
| :------------------ | :----------------------- | :--------------------------------: | :--------------------------------: | :--------------------------------: | :--------------------------------: | :--------------------------------: |
| **Formalization**   | **Task**                 |                                    |                                    |                                    |                                    |                                    |
| Retrieval           | Question answering       | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
|                     | article retrieval        | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
| bitext Mining       | dialect pairing          | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |                                    |
| Classification      | Political                | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> | <span style="color:green">✓</span> |                                    |
|                     | Language Identification  | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |
|                     | Linguistic Acceptability | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |
|                     | Sentiment/Hate Speech    | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
|                     | Dialog Systems           | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> | <span style="color:green">✓</span> |
| Clustering          | Thematic Clustering      | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |                                    | <span style="color:green">✓</span> |
| Reranking           |                          |                                    |                                    |                                    |                                    |                                    |
| Pair Classification |                          |                                    |                                    |                                    |                                    |                                    |
| STS                 |                          |                                    |                                    |                                    |                                    |                                    |


